/**
  This is a basic scaffold of a sub application. You will notice that it is
  almost identical to a typical Y.App and that is by design.

  Notes:
  Route paths need to end in a / ie) 'path/to/:id/'
  When specifying routes under the 'charmstore' namespace reference the parent
      routes to ensure that you aren't clashing with another route
  Do not specify a route for '/' under the 'charmstore' namespace
      as it will clash with the parent app
  To change routes call the sub apps navigate() method with the appropriate path

  Setup
  -----
  1. Add a container element to the index.html file
  2. Specify that container element in the `container` attribute
  3. Require your sub application files into the Y instance as usual
  4. Add the SubAppRegistration extension to the parent Y.App instance
    a. Require `app-subapp-extension` into the parent Y.App instance
    b. Add the `Y.juju.SubAppRegistration` extension to the parent Y.App instance
  5. Add the `subApplications` property to the parent Y.App prototype ex)
    subApplications: [{
        type: Y.juju.ScaffoldSubApp,
        config: {}
      }]
  6. Call the `addSubApplications` method, provided by the extension at the end
      of the parent applications initializer ex) `this.addSubApplications()`
*/
YUI.add('scaffold-sub-app', function(Y) {

    Y.namespace('juju').ScaffoldSubApp = Y.Base.create('scaffold-sub-app', Y.juju.SubApp, [], {

        views: {
            viewOne: {
                type: 'juju.ScaffoldViewOne',
                preserve: false
            },
            viewTwo: {
                type: 'juju.ScaffoldViewTwo',
                preserve: false
            }
        },

        initializer: function() {},

        showViewOne: function(req, res, next) {
            console.log('showViewOne', this.name);
            this.showView('viewOne');
            this.navigate('/part/7');
            next();
        },

        showViewTwo: function(req, res, next) {
            console.log('showViewTwo', this.name);
            this.showView('viewTwo');
            next();
        },

        destructor: function() {}

    }, {
        ATTRS: {
            container: {
                value: Y.one('#scaffold-subapp-container')
            },
            urlNamespace: {
                value: 'charmstore'
            },
            routes: {
                value: [
                    { path: '/', callbacks: 'showViewOne' },
                    { path: '/part/:id/', callbacks: 'showViewTwo' },
                ]
            }
        }
    });

}, '0.1.0', {requires: ['sub-app', 'scaffold-view-one', 'scaffold-view-two']});
